@@ -2,7 +2,7 @@ package Spreadsheet::XLSX::Reader::LibXML::Cell;
 BEGIN {
   $Spreadsheet::XLSX::Reader::LibXML::Cell::AUTHORITY = 'cpan:JANDREW';
 }
-use version; our $VERSION = qv('v0.14.2');
+use version; our $VERSION = qv('v0.16.2');
 
 use 5.010;
 use Moose;
@@ -254,6 +254,16 @@ background of this class.  All data has been pre-coalated/built from the L<Works
 will populate the attributes of this class when it is generated.  If you want to use it 
 as a standalone class just fill in the L<Attributes|/Attributes> below.
 
+This class uses a role for full functional implementation.  Read the documentation 
+for each of the role as well as this documentation to gain a complete picture of this 
+class.
+
+=head2 with
+
+These are attached role(s) for additional (re-used) functionality
+
+=head3 L<Spreadsheet::XLSX::Reader::LibXML::LogSpace>
+
 =head2 Primary Methods
 
 These are methods used to transform data stored in the L<Attributes|/Attributes> 
@@ -967,7 +977,23 @@ This software is copyrighted (c) 2014 by Jed
 
 =over
 
-L<Spreadsheet::XLSX::Reader::LibXML>
+L<version>
+
+B<5.010> - (L<perl>)
+
+L<Moose>
+
+L<MooseX::StrictConstructor>
+
+L<MooseX::HasDefaults::RO>
+
+L<Types::Standard>
+
+L<lib>
+
+L<Spreadsheet::XLSX::Reader::LibXML::LogSpace>
+
+L<Spreadsheet::XLSX::Reader::LibXML::Types>
 
 =back
 
